[![Build Status](https://travis-ci.org/CoCongV/sanic-restful.svg?branch=develop)](https://travis-ci.org/CoCongV/sanic-restful)
[![codebeat badge](https://codebeat.co/badges/05407b18-a508-4cde-ac35-8e6776ea20e1)](https://codebeat.co/projects/github-com-cocongv-sanic-restful-develop)
[![Maintainability](https://api.codeclimate.com/v1/badges/bb199b737ab079fd7b0c/maintainability)](https://codeclimate.com/github/CoCongV/sanic-restful/maintainability)
[![Test Coverage](https://api.codeclimate.com/v1/badges/bb199b737ab079fd7b0c/test_coverage)](https://codeclimate.com/github/CoCongV/sanic-restful/test_coverage)
[![PyPI version](https://badge.fury.io/py/sanic-restful.svg)](https://badge.fury.io/py/sanic-restful)
[![](https://img.shields.io/pypi/pyversions/sanic-restful.svg)](https://pypi.org/project/sanic-restful/)
# Sanic-RESTful

(Developing)
Sanic-RESTful provides the building blocks for creating a great REST API.

## User Guide

You'll find the user guide and all documentation [here](https://flask-restful.readthedocs.io/)

likely flask-restful